@@ -5,7 +5,9 @@
 #
 # Imports =====================================================================
 import dhtmlparser
-from dhtmlparser.htmlelement import _rotate_buff, _closeElements
+from dhtmlparser import first
+from dhtmlparser.htmlelement import _rotate_buff
+from dhtmlparser.htmlelement import _closeElements
 
 
 # Functions & objects =========================================================
@@ -37,8 +39,8 @@ def test_closeElements():
     assert xe
     assert not xe[0].endtag
 
-    tag.chids = _closeElements(tag.childs)
+    tag.chids = _closeElements(tag.childs, dhtmlparser.HTMLElement)
 
     xe = tag.find("xe")
     assert xe
-    assert xe[0].endtag
+    assert first(xe).endtag
