@@ -5,6 +5,7 @@
 #
 # Imports =====================================================================
 import dhtmlparser
+from dhtmlparser import first
 
 
 # Variables ===================================================================
@@ -22,18 +23,18 @@ DOM = dhtmlparser.parseString("""
     </div>
 """)
 div = DOM.find("div")[-1]
-br = div.find("br")[0]
+br = first(div.find("br"))
 
 
 # Functions & objects =========================================================
 def test_isTag():
     assert div.isTag()
-    assert not div.childs[0].isTag()
+    assert not first(div.childs).isTag()
 
 
 def test_isEndTag():
     assert not div.isEndTag()
-    assert not div.childs[0].isEndTag()
+    assert not first(div.childs).isEndTag()
 
     assert div.endtag.isEndTag()
 
@@ -41,7 +42,7 @@ def test_isEndTag():
 def test_isNonPairTag():
     assert not div.isNonPairTag()
 
-    text = div.childs[0]
+    text = first(div.childs)
     assert text.getTagName().strip() == "Second."
 
     assert not text.isTag()
@@ -52,14 +53,14 @@ def test_isNonPairTag():
 
 def test_isComment():
     assert not div.isComment()
-    assert not div.childs[0].isComment()
+    assert not first(div.childs).isComment()
 
     assert div.childs[-2].isComment()
 
 
 def test_isOpeningTag():
     assert div.isOpeningTag()
-    assert not div.childs[0].isOpeningTag()
+    assert not first(div.childs).isOpeningTag()
 
     assert not br.isOpeningTag()
 
@@ -70,14 +71,14 @@ def test_isEndTagTo():
 
 def test_tagToString():
     assert div.tagToString() == '<div id="second">'
-    assert div.childs[0].tagToString() == '\n        Second.\n        '
+    assert first(div.childs).tagToString() == '\n        Second.\n        '
 
     assert br.tagToString() == "<br />"
 
 
 def test_getTagName():
     assert div.getTagName() == 'div'
-    assert div.childs[0].getTagName() == '\n        Second.\n        '
+    assert first(div.childs).getTagName() == '\n        Second.\n        '
 
     assert br.getTagName() == "br"
 
@@ -85,14 +86,14 @@ def test_getTagName():
 def test_getContent():
     match = '\n        Second.\n        <br />\n        <!-- comment -->\n    '
     assert div.getContent() == match
-    assert div.childs[0].getContent() == '\n        Second.\n        '
+    assert first(div.childs).getContent() == '\n        Second.\n        '
 
     assert br.getContent() == ""
 
 
 def test_toString():
     assert div.toString().startswith(div.tagToString())
-    assert div.childs[0].toString() == '\n        Second.\n        '
+    assert first(div.childs).toString() == '\n        Second.\n        '
     assert br.toString() == "<br />"
 
 
@@ -104,7 +105,7 @@ def test_isNonPairTag_setter():
 
 def test_containsParamSubset():
     dom = dhtmlparser.parseString("<div id=x class=xex></div>")
-    div = dom.find("div")[0]
+    div = first(dom.find("div"))
 
     assert div.containsParamSubset({"id": "x"})
     assert div.containsParamSubset({"class": "xex"})
